==> haskell-asn1-parse-0.9.4-74-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-HL06w6fp5Ca8AuukmGe5YZ
key: asn1-parse-0.9.4-HL06w6fp5Ca8AuukmGe5YZ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 68cb5c9a56aadf555a0a80210b676898
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-HL06w6fp5Ca8AuukmGe5YZ
depends:
    asn1-encoding-0.9.5-DDyi2ItguO01dpepVrV8LU
    asn1-types-0.3.2-JtmyLcWjlAM5Ek6K2mGfDx base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-DDyi2ItguO01dpepVrV8LU=6dac9042b707027721edcf7f2cdc15df
             asn1-types-0.3.2-JtmyLcWjlAM5Ek6K2mGfDx=bebffe716cd0d972f4600c0542e59d35
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-76-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-43rARflqKD9QmPmhSGHKt
key: asn1-parse-0.9.4-43rARflqKD9QmPmhSGHKt
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 97b0fff8ada724832e41282372c66b8a
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-43rARflqKD9QmPmhSGHKt
depends:
    asn1-encoding-0.9.5-2sNG6Jbqz8FIHqFopEwd9s
    asn1-types-0.3.2-3RwAdHw1cBjFrGsSnhhLWY base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-2sNG6Jbqz8FIHqFopEwd9s=3722e0fbe652d5043f982ba533c2098b
             asn1-types-0.3.2-3RwAdHw1cBjFrGsSnhhLWY=763daf51ab10462f441f8d6e4d30d663
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
